| Title: | Calculate Regional Consistency Probabilities for Multi-Regional Clinical Trials |
|---|---|
| Description: | Provides methods to calculate approximate regional consistency probabilities using Method 1 and Method 2 proposed by the Japanese Ministry of Health, Labor and Welfare (2007) <https://www.pmda.go.jp/files/000153265.pdf>. These methods are useful for assessing regional consistency in multi-regional clinical trials. The package can calculate unconditional, joint, and conditional regional consistency probabilities. For technical details, please see Homma (2024) <doi:10.1002/pst.2358>. |
| Authors: | Gosuke Homma [aut, cre] |
| Maintainer: | Gosuke Homma <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 1.0.0 |
| Built: | 2026-05-13 06:11:13 UTC |
| Source: | https://github.com/gosukehommaex/regionalconsistency |
This function calculates approximate regional consistency probabilities using Methods 1 and 2 proposed by Japanese MHLW (2007). The function can obtain:
Unconditional regional consistency probabilities
Joint regional consistency probabilities
Conditional regional consistency probabilities
For technical details, please see Homma (2024)
regional.consistency.probs(f.s, PI, alpha, power, seed)regional.consistency.probs(f.s, PI, alpha, power, seed)
f.s |
A numeric vector representing the proportion of patients in region s(=1,...,S) among patients in the entire trial population. Values must sum to 1. |
PI |
A numeric value specifying the threshold for Method 1 (typically set at 0.5). |
alpha |
A numeric value representing the one-sided level of significance. |
power |
A numeric value representing the target power. |
seed |
A random number seed. |
A list containing the following components:
The input proportion of patients in each region
The input threshold value for Method 1
The input one-sided significance level
The input target power
The input seed number
Unconditional regional consistency probability for Method 1
Joint regional consistency probability for Method 1
Conditional regional consistency probability for Method 1
Unconditional regional consistency probability for Method 2
Joint regional consistency probability for Method 2
Conditional regional consistency probability for Method 2
regional.consistency.probs( f.s = c(0.1, 0.45, 0.45), PI = 0.5, alpha = 0.025, power = 0.8, seed = 123 )regional.consistency.probs( f.s = c(0.1, 0.45, 0.45), PI = 0.5, alpha = 0.025, power = 0.8, seed = 123 )